+++
title = "Table name"
description = "Testing `#+name` and table."
tags = ["table"]
draft = false
+++

<a id="table--only-name"></a>

| h1  | h2  |
|-----|-----|
| abc | def |

<a id="table--name-and-caption"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--name-and-caption">Table 1</a></span>:
  An Org table with both <code>#+name</code> and <code>#+caption</code>
</div>

| h1  | h2  |
|-----|-----|
| abc | def |
